@@ -28,9 +28,10 @@ class StringUtil(object):
         s = StringUtil.and_pattern.sub('-and-', s)
         s = StringUtil.at_pattern.sub('-at-', s)
         s = StringUtil.hyphen_pattern.sub('-', s)
+        s = StringUtil.trim_pattern.sub('', s)
         return s
 
     @staticmethod
     def slug_words(slug):
         """extract words from slug, separated by whitespaces"""
-        return slug.replace('-and-', '-').replace('-at-', '-').replace('-', ' ')
+        return slug.replace('-and-', '-').replace('-at-', '-').replace('-', ' ').strip()
